Module interprocess::local_socket::prelude

source ·
Re-exports of traits done in a way that doesn’t pollute the scope, as well as of the enum-dispatch types with their names prefixed with LocalSocket.

Re-exports