ConnectOptions

Struct ConnectOptions 

pub struct ConnectOptions<'n> { /* private fields */ }
Client-side builder for local socket streams, including Stream.

Implementations

Source

impl ConnectOptions<'_>

Creation and ownership.

pub fn new() -> Self

Returns a default set of client options.

Source

impl<'n> ConnectOptions<'n>

Option setters.

pub fn name(self, name: Name<'n>) -> Self

Sets the name the client will connect to.

pub fn wait_mode(self, wait_mode: ConnectWaitMode) -> Self

Sets the wait mode of the connection operation.

This defaults to unbounded waiting.

Platform-specific behavior
Unix

Number of additional fcntls if SOCK_NONBLOCK is available:

wait_mode \ nonblocking_streamfalsetrue
Unbounded01
Timeout10
Deferred10

Number of additional fcntls if SOCK_NONBLOCK is not available:

wait_mode \ nonblocking_streamfalsetrue
Unbounded01
Timeout21
Deferred21
Windows

WaitMode::Timeout has no effect in that attempting to connect to an overloaded named pipe will always return an error as soon as possible. If the named pipe is across the network, this may entail blocking on network activity for a duration that exceeds the specified timeout.

WaitMode::Deferred is not supported, and an error will be returned by connect_* if it is used.

pub fn nonblocking_stream(self, nonblocking: bool) -> Self

Sets whether the resulting connection is to have its reads and writes be nonblocking or not.

This is disabled by default.

Platform-specific behavior
Unix

See wait_mode.

Windows

The same as .set_nonblocking(true) immediately after creation.

Source

impl ConnectOptions<'_>

Stream constructors.

pub fn connect_sync(&self) -> Result<Stream>

Creates a Stream by connecting to the specified local socket name.

On platforms where there are multiple available implementations, this dispatches to the appropriate implementation based on where the name points to.

pub fn connect_sync_as<S: Stream>(&self) -> Result<S>

Creates the given type of stream by connecting to the specified local socket name.

pub fn connect_tokio( &self, ) -> impl Future<Output = Result<TokioStream>> + Send + Sync + '_

Available on crate feature tokio only.

Creates a Tokio Stream by connecting to the specified local socket name.

On platforms where there are multiple available implementations, this dispatches to the appropriate implementation based on where the name points to.

pub fn connect_tokio_as<S: Stream>( &self, ) -> impl Future<Output = Result<S>> + Send + Sync + '_

Available on crate feature tokio only.

Creates the given type of Tokio stream by connecting to the specified local socket name.