pub struct LocalSocketStream { /* private fields */ }
Available on crate feature tokio_support only.
A Tokio-based local socket byte stream, obtained eiter from LocalSocketListener or by connecting to an existing local socket.

Examples

Implementations

Connects to a remote local socket server.

Splits a stream into a read half and a write half, which can be used to read and write the stream concurrently.

Retrieves the identifier of the process on the opposite end of the local socket connection.

Platform-specific behavior
macOS and iOS

Not supported by the OS, will always generate an error at runtime.