Struct interprocess::nonblocking::local_socket::Incoming
source · pub struct Incoming { /* private fields */ }👎Deprecated: does not integrate with async runtimes, leading to poor performance and bugs related to reading and writing at the same time (you can’t) – see the
tokio modules for relevant IPC primitives or open an issue if you want more async runtimes to be supported as wellAvailable on crate feature
nonblocking only.Expand description
An infinite asynchronous stream over incoming client connections of a LocalSocketListener.
This stream is created by the incoming method on LocalSocketListener – see its documentation for more.