pub struct UdStream { /* private fields */ }
Available on Unix only.
A Unix domain socket byte stream, obtained either from UdStreamListener or by connecting to an existing server.

Examples

Basic example:

use interprocess::os::unix::udsocket::UdStream;
use std::io::prelude::*;

let mut conn = UdStream::connect("/tmp/example1.sock")?;
conn.write_all(b"Hello from client!")?;
let mut string_buffer = String::new();
conn.read_to_string(&mut string_buffer)?;
println!("Server answered: {}", string_buffer);

Implementations

Connects to a Unix domain socket server at the specified path.

See ToUdSocketPath for an example of using various string types to specify socket paths.

System calls
  • socket
  • connect

Receives bytes from the socket stream.

System calls
  • read

Receives bytes from the socket stream, making use of scatter input for the main data.

System calls
  • readv

Receives both bytes and ancillary data from the socket stream.

The ancillary data buffer is automatically converted from the supplied value, if possible. For that reason, mutable slices of bytes (u8 values) can be passed directly.

System calls
  • recvmsg

Receives bytes and ancillary data from the socket stream, making use of scatter input for the main data.

The ancillary data buffer is automatically converted from the supplied value, if possible. For that reason, mutable slices of bytes (u8 values) can be passed directly.

System calls
  • recvmsg

Sends bytes into the socket stream.

System calls
  • write

Sends bytes into the socket stream, making use of gather output for the main data.

System calls
  • senv

Sends bytes and ancillary data into the socket stream.

The ancillary data buffer is automatically converted from the supplied value, if possible. For that reason, slices and Vecs of AncillaryData can be passed directly.

System calls
  • sendmsg

Sends bytes and ancillary data into the socket stream, making use of gather output for the main data.

The ancillary data buffer is automatically converted from the supplied value, if possible. For that reason, slices and Vecs of AncillaryData can be passed directly.

System calls
  • sendmsg

Shuts down the read, write, or both halves of the stream. See Shutdown.

Attempting to call this method with the same how argument multiple times may return Ok(()) every time or it may return an error the second time it is called, depending on the platform. You must either avoid using the same value twice or ignore the error entirely.

Enables or disables the nonblocking mode for the stream. By default, it is disabled.

In nonblocking mode, calls to the recv… methods and the Read trait methods will never wait for at least one byte of data to become available; calls to send… methods and the Write trait methods will never wait for the other side to remove enough bytes from the buffer for the write operation to be performed. Those operations will instead return a WouldBlock error immediately, allowing the thread to perform other useful operations in the meantime.

Checks whether the stream is currently in nonblocking mode or not.

Available on Linux and (GNU or musl or target_env="musleabi" or target_env="musleabihf"), or Emscripten, or Redox, or Haiku only.

Fetches the credentials of the other end of the connection without using ancillary data. The returned structure contains the process identifier, user identifier and group identifier of the peer.