pub struct ByteWriterPipeStream { /* private fields */ }
Available on Windows only.
Byte stream writer for a named pipe.

Created either by using PipeListener or by connecting to a named pipe server.

Implementations

Connects to the specified named pipe (the \\.\pipe\ prefix is added automatically), blocking until a server instance is dispatched.

Connects to the specified named pipe at a remote computer (the \\<hostname>\pipe\ prefix is added automatically), blocking until a server instance is dispatched.

Sets whether the nonblocking mode for the pipe stream is enabled. By default, it is disabled.

In nonblocking mode, attempts to read from the pipe when there is no data available or to write when the buffer has filled up because the receiving side did not read enough bytes in time will never block like they normally do. Instead, a WouldBlock error is immediately returned, allowing the thread to perform useful actions in the meantime.

If called on the server side, the flag will be set only for one stream instance. A listener creation option, nonblocking, and a similar method on the listener, set_nonblocking, can be used to set the mode in bulk for all current instances and future ones.

Returns true if the stream was created by a listener (server-side), false if it was created by connecting to a server (server-side).

Returns true if the stream was created by connecting to a server (client-side), false if it was created by a listener (server-side).

Retrieves the process identifier of the client side of the named pipe connection.

Retrieves the session identifier of the client side of the named pipe connection.

Retrieves the process identifier of the server side of the named pipe connection.

Retrieves the session identifier of the server side of the named pipe connection.

Disconnects the named pipe stream without flushing buffers, causing all data in those buffers to be lost. This is much faster (and, in some case, the only finite-time way of ending things) than simply dropping the stream, since, for non-async named pipes, the Drop implementation flushes first.

Only makes sense for server-side pipes and will return an error if called on a client stream. For async pipe streams, this is the same as dropping the pipe.