pub struct DuplexMsgPipeStream { /* private fields */ }
Available on Windows and crate feature tokio_support only.
Message stream reader and writer for a Tokio-based named pipe.

Created either by using PipeListener or by connecting to a named pipe server.

Implementations

Tries to connect to the specified named pipe (the \\.\pipe\ prefix is added automatically).

If there is no available server, returns immediately with the WouldBlock error.

Tries to connect to the specified named pipe at a remote computer (the \\<hostname>\pipe\ prefix is added automatically).

If there is no available server, returns immediately with the WouldBlock error.

Returns true if the stream was created by a listener (server-side), false if it was created by connecting to a server (client-side).

Returns true if the stream was created by connecting to a server (client-side), false if it was created by a listener (server-side).

Creates a Tokio-based async object from a given raw handle. This will also attach the object to the Tokio runtime this function is called in, so calling it outside a runtime will result in an error (which is why the FromRawHandle trait can’t be implemented instead).

Safety

The given handle must be valid (i.e. refer to an existing kernel object) and must not be owned by any other handle container. If this is not upheld, an arbitrary handle will be closed when the returned object is dropped.

Splits the duplex stream into its reading and writing half.

Retrieves the process identifier of the client side of the named pipe connection.

Retrieves the session identifier of the client side of the named pipe connection.

Retrieves the process identifier of the server side of the named pipe connection.

Retrieves the session identifier of the server side of the named pipe connection.

Disconnects the named pipe stream without flushing buffers, causing all data in those buffers to be lost. This is much faster (and, in some case, the only finite-time way of ending things) than simply dropping the stream, since, for non-async named pipes, the Drop implementation flushes first.

Only makes sense for server-side pipes and will return an error if called on a client stream. For async pipe streams, this is the same as dropping the pipe.