pub struct UnnamedPipeWriter { /* private fields */ }
A handle to the writing end of an unnamed pipe, created by the pipe function together with the reading end.

The core functionality is exposed in a file-like Write interface. On Windows, the ShareHandle and As-/Into-/FromRawHandle traits are also implemented, along with As-/Into-/FromRawFd on Unix.