pub enum ConnectWaitMode {
Deferred,
Timeout(Duration),
Unbounded,
}Expand description
Describes how a client connection operation should wait for the server to accept it.
Variants
Deferred
The connection operation returns immediately. Subsequent I/O operations will block until the connection actually becomes established. If a connection error occurs in the background, that error will be returned by the next I/O operation on the returned object.
Timeout(Duration)
A wait state is entered until the connection becomes established which lasts for up to the
given amount of time. An error of kind TimedOut is
returned if it does not become established within that timeframe.
Unbounded
A wait state is entered until the connection becomes established. This wait state may last for an indefinite amount of time.