Struct interprocess::local_socket::tokio::LocalSocketStream
source · pub struct LocalSocketStream { /* private fields */ }Available on crate feature
tokio_support only.Expand description
A Tokio-based local socket byte stream, obtained eiter from LocalSocketListener or by connecting to an existing local socket.
Examples
Implementations
sourceimpl LocalSocketStream
impl LocalSocketStream
sourcepub async fn connect<'a>(name: impl ToLocalSocketName<'a>) -> Result<Self>
pub async fn connect<'a>(name: impl ToLocalSocketName<'a>) -> Result<Self>
Connects to a remote local socket server.
sourcepub fn into_split(self) -> (OwnedReadHalf, OwnedWriteHalf)
pub fn into_split(self) -> (OwnedReadHalf, OwnedWriteHalf)
Splits a stream into a read half and a write half, which can be used to read and write the stream concurrently.
sourcepub fn peer_pid(&self) -> Result<u32>
pub fn peer_pid(&self) -> Result<u32>
Retrieves the identifier of the process on the opposite end of the local socket connection.
Platform-specific behavior
macOS and iOS
Not supported by the OS, will always generate an error at runtime.