Struct interprocess::local_socket::tokio::OwnedReadHalf
source · pub struct OwnedReadHalf { /* private fields */ }Available on crate feature
tokio_support only.Expand description
An owned read half of a Tokio-based local socket stream, obtained by splitting a LocalSocketStream.
Examples
Implementations
sourceimpl OwnedReadHalf
impl OwnedReadHalf
sourcepub fn peer_pid(&self) -> Result<u32>
pub fn peer_pid(&self) -> Result<u32>
Retrieves the identifier of the process on the opposite end of the local socket connection.
Platform-specific behavior
macOS and iOS
Not supported by the OS, will always generate an error at runtime.