Struct interprocess::os::windows::named_pipe::tokio::DuplexMsgPipeStream
source · pub struct DuplexMsgPipeStream { /* private fields */ }tokio_support only.Expand description
Implementations
sourceimpl DuplexMsgPipeStream
impl DuplexMsgPipeStream
sourcepub fn connect(name: impl AsRef<OsStr>) -> Result<Self>
pub fn connect(name: impl AsRef<OsStr>) -> Result<Self>
Tries to connect to the specified named pipe (the \\.\pipe\ prefix is added automatically).
If there is no available server, returns immediately with the WouldBlock error.
sourcepub fn connect_to_remote(
pipe_name: impl AsRef<OsStr>,
hostname: impl AsRef<OsStr>
) -> Result<Self>
pub fn connect_to_remote(
pipe_name: impl AsRef<OsStr>,
hostname: impl AsRef<OsStr>
) -> Result<Self>
Tries to connect to the specified named pipe at a remote computer (the \\<hostname>\pipe\ prefix is added automatically).
If there is no available server, returns immediately with the WouldBlock error.
sourcepub fn is_server(&self) -> bool
pub fn is_server(&self) -> bool
Returns true if the stream was created by a listener (server-side), false if it was created by connecting to a server (client-side).
sourcepub fn is_client(&self) -> bool
pub fn is_client(&self) -> bool
Returns true if the stream was created by connecting to a server (client-side), false if it was created by a listener (server-side).
sourcepub unsafe fn from_raw_handle(handle: *mut c_void) -> Result<Self>
pub unsafe fn from_raw_handle(handle: *mut c_void) -> Result<Self>
Creates a Tokio-based async object from a given raw handle. This will also attach the object to the Tokio runtime this function is called in, so calling it outside a runtime will result in an error (which is why the FromRawHandle trait can’t be implemented instead).
Safety
The given handle must be valid (i.e. refer to an existing kernel object) and must not be owned by any other handle container. If this is not upheld, an arbitrary handle will be closed when the returned object is dropped.
sourcepub fn split(self) -> (MsgReaderPipeStream, MsgWriterPipeStream)
pub fn split(self) -> (MsgReaderPipeStream, MsgWriterPipeStream)
Splits the duplex stream into its reading and writing half.
sourcepub fn client_process_id(&self) -> Result<u32>
pub fn client_process_id(&self) -> Result<u32>
Retrieves the process identifier of the client side of the named pipe connection.
sourcepub fn client_session_id(&self) -> Result<u32>
pub fn client_session_id(&self) -> Result<u32>
Retrieves the session identifier of the client side of the named pipe connection.
sourcepub fn server_process_id(&self) -> Result<u32>
pub fn server_process_id(&self) -> Result<u32>
Retrieves the process identifier of the server side of the named pipe connection.
sourcepub fn server_session_id(&self) -> Result<u32>
pub fn server_session_id(&self) -> Result<u32>
Retrieves the session identifier of the server side of the named pipe connection.
sourcepub fn disconnect_without_flushing(self) -> Result<()>
pub fn disconnect_without_flushing(self) -> Result<()>
Disconnects the named pipe stream without flushing buffers, causing all data in those buffers to be lost. This is much faster (and, in some case, the only finite-time way of ending things) than simply dropping the stream, since, for non-async named pipes, the Drop implementation flushes first.
Only makes sense for server-side pipes and will return an error if called on a client stream. For async pipe streams, this is the same as dropping the pipe.